package hu.bme.mit.books.manager;

import hu.bme.mit.books.model.Book;

import java.util.ArrayList;
import java.util.List;

public class BookManager {

	List<Book> books;

	/**
	 * Instantiates a new book manager with three sample books.
	 */
	public BookManager() {
		books = new ArrayList<Book>();
		addBook("Terry Pratchett", "The Light Fantastic", 232, true);
		addBook("Neil Gaiman", "American Gods", 560, true);
		addBook("Test author", "Test Book", 123, false);
	}

	/**
	 * Gets the number of books.
	 * 
	 * @return the number of books
	 */
	public int getNumberOfBooks() {
		return books.size();
	}

	/**
	 * Gets the book of id.
	 * 
	 * @param no
	 *            the book id, that is between 0 and getNumberOfBooks()-1 (such
	 *            as an array index).
	 * @return the book with the given id, or null if it does not exists
	 */
	public Book getBookOfID(int no) {
		return books.get(no);
	}

	/**
	 * Gets the all books.
	 * 
	 * @return the all books
	 */
	public List<Book> getAllBooks() {
		return new ArrayList<Book>(books);
	}

	/**
	 * Gets all read books.
	 * 
	 * @return the read books
	 */
	public List<Book> getReadBooks() {
		ArrayList<Book> readBooks = new ArrayList<Book>();
		for (Book book : books) {
			if (book.isRead())
				readBooks.add(book);
		}
		return readBooks;
	}

	/**
	 * Gets the book of an author.
	 * 
	 * @param author
	 *            the author
	 * @return the book of author
	 */
	public List<Book> getBookOfAuthor(String author) {
		ArrayList<Book> readBooks = new ArrayList<Book>();
		for (Book book : books) {
			if (book.getAuthor().contentEquals(author))
				readBooks.add(book);
		}
		return readBooks;
	}

	/**
	 * Adds a book with a given author, title, page number to the manager, and
	 * sets whether it is read or not.
	 * 
	 * @param author
	 *            the author
	 * @param title
	 *            the title
	 * @param pages
	 *            the pages
	 * @param read
	 *            the read
	 */
	public void addBook(String author, String title, int pages, boolean read) {
		Book book = new Book();
		book.setAuthor(author);
		book.setTitle(title);
		book.setPageNum(pages);
		book.setRead(read);
		books.add(book);
	}
}
